AttachmentService class

Constructors

AttachmentService(RestHelper _restHelper)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile(File file, {String? fileName, String? doctype, String? docname, bool isPrivate = true}) Future<Map<String, dynamic>>
Uploads a file and optionally attaches it to a document.

Operators

operator ==(Object other) bool
The equality operator.
inherited