QueryBuilder class
A fluent builder for constructing ERPNext queries.
Constructors
- QueryBuilder(DoctypeService _service, String doctype)
Properties
Methods
-
filters(
List< List> filters) → QueryBuilder - Add multiple filters at once.
-
first(
) → Future< Map< String, dynamic> ?> - Execute and return the first result or null.
-
get(
) → Future< List> - Execute the query and return a list of maps.
-
limit(
int pageLength, {int start = 0}) → QueryBuilder - Set pagination limits.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orderBy(
String field, {bool descending = false}) → QueryBuilder - Set sorting. e.g. 'creation desc'
-
select(
List< String> fields) → QueryBuilder - Specify fields to fetch.
-
toString(
) → String -
A string representation of this object.
inherited
-
where(
String field, dynamic operatorOrValue, [dynamic value]) → QueryBuilder - Add a filter.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited